==> JobOffers-0.4.0-py2.py3-none-any.whl: job_offers/mails.py <==
# -*- coding: utf-8 -*-

from django.core.mail import EmailMultiAlternatives
from django.conf import settings
from django.template.loader import render_to_string


class BaseMail(object):
    subject_template = None
    body_template = None
    body_html_template = None

    def __init__(self, subject_template=None, body_template=None, body_html_template=None):
        self.subject_template = subject_template or self.__class__.subject_template
        self.body_template = body_template or self.__class__.body_template
        self.body_html_template = body_html_template or self.__class__.body_html_template

    def get_email(self, site, application, **extra):
        context = {
            'site': site,
            'application': application,
        }
        context.update(extra)
        message = EmailMultiAlternatives(
            self.render_subject(context),
            self.render_body(context),
            self.get_from_email_address(context),
            self.get_to_email_addresses(context),
        )
        message.attach_alternative(self.render_body_html(context), 'text/html')
        return message

    def render_subject(self, context):
        return render_to_string(self.subject_template, context).replace(u'\n', u' ')

    def render_body(self, context):
        return render_to_string(self.body_template, context)

    def render_body_html(self, context):
        return render_to_string(self.body_html_template, context)

    def get_from_email_address(self, context):
        return settings.JOB_OFFER_FROM_EMAIL

    def get_to_email_addresses(self, context):
        raise NotImplementedError()


class BaseCandidateConfirmationMail(BaseMail):
    def get_to_email_addresses(self, context):
        return [context['application'].email]


class SpecApplicationConfirmationMail(BaseCandidateConfirmationMail):
    subject_template = 'job_offers/mails/speculative-application-confirmation-subject.txt'
    body_template = 'job_offers/mails/speculative-application-confirmation-body.txt'
    body_html_template = 'job_offers/mails/speculative-application-confirmation-body.html'


class JobOfferConfirmationMail(BaseCandidateConfirmationMail):
    subject_template = 'job_offers/mails/job-offer-confirmation-subject.txt'
    body_template = 'job_offers/mails/job-offer-confirmation-body.txt'
    body_html_template = 'job_offers/mails/job-offer-confirmation-body.html'


class AdminNotificationMail(BaseMail):
    subject_template = 'job_offers/mails/admin-notification-subject.txt'
    body_template = 'job_offers/mails/admin-notification-body.txt'
    body_html_template = 'job_offers/mails/admin-notification-body.html'

    def get_to_email_addresses(self, context):
        if context['job_offer']:
            contact = context['job_offer'].contact
            if contact is not None and contact.description:
                return [contact.description]
        return settings.JOB_OFFER_ADMIN_EMAILS

    def get_email(self, site, application, **extra):
        extra['job_offer'] = application.job_offer
        email = super(AdminNotificationMail, self).get_email(site, application, **extra)

        email.attach(application.cv.name, application.cv.read())
        if application.cover_letter:
            email.attach(application.cover_letter.name, application.cover_letter.read())
        if application.other_document:
            email.attach(application.other_document.name, application.other_document.read())
        return email

==> JobOffers-0.5.0-py2.py3-none-any.whl: job_offers/mails.py <==
# -*- coding: utf-8 -*-

from django.core.mail import EmailMultiAlternatives
from django.conf import settings
from django.template.loader import render_to_string


class BaseMail(object):
    subject_template = None
    body_template = None
    body_html_template = None

    def __init__(self, subject_template=None, body_template=None, body_html_template=None):
        self.subject_template = subject_template or self.__class__.subject_template
        self.body_template = body_template or self.__class__.body_template
        self.body_html_template = body_html_template or self.__class__.body_html_template

    def get_email(self, site, application, **extra):
        context = {
            'site': site,
            'application': application,
        }
        context.update(extra)
        message = EmailMultiAlternatives(
            self.render_subject(context),
            self.render_body(context),
            self.get_from_email_address(context),
            self.get_to_email_addresses(context),
        )
        message.attach_alternative(self.render_body_html(context), 'text/html')
        return message

    def render_subject(self, context):
        return render_to_string(self.subject_template, context).replace(u'\n', u' ')

    def render_body(self, context):
        return render_to_string(self.body_template, context)

    def render_body_html(self, context):
        return render_to_string(self.body_html_template, context)

    def get_from_email_address(self, context):
        return settings.JOB_OFFER_FROM_EMAIL

    def get_to_email_addresses(self, context):
        raise NotImplementedError()


class BaseCandidateConfirmationMail(BaseMail):
    def get_to_email_addresses(self, context):
        return [context['application'].email]


class SpecApplicationConfirmationMail(BaseCandidateConfirmationMail):
    subject_template = 'job_offers/mails/speculative-application-confirmation-subject.txt'
    body_template = 'job_offers/mails/speculative-application-confirmation-body.txt'
    body_html_template = 'job_offers/mails/speculative-application-confirmation-body.html'


class JobOfferConfirmationMail(BaseCandidateConfirmationMail):
    subject_template = 'job_offers/mails/job-offer-confirmation-subject.txt'
    body_template = 'job_offers/mails/job-offer-confirmation-body.txt'
    body_html_template = 'job_offers/mails/job-offer-confirmation-body.html'

    def get_email(self, site, application, **extra):
        extra['job_offer'] = application.job_offer
        return super(JobOfferConfirmationMail, self).get_email(site, application, **extra)


class AdminNotificationMail(BaseMail):
    subject_template = 'job_offers/mails/admin-notification-subject.txt'
    body_template = 'job_offers/mails/admin-notification-body.txt'
    body_html_template = 'job_offers/mails/admin-notification-body.html'

    def get_to_email_addresses(self, context):
        if context['job_offer']:
            contact = context['job_offer'].contact
            if contact is not None and contact.description:
                return [contact.description.strip()]
        return settings.JOB_OFFER_ADMIN_EMAILS

    def get_email(self, site, application, **extra):
        extra['job_offer'] = application.job_offer
        email = super(AdminNotificationMail, self).get_email(site, application, **extra)

        email.attach(application.cv.name, application.cv.read())
        if application.cover_letter:
            email.attach(application.cover_letter.name, application.cover_letter.read())
        if application.other_document:
            email.attach(application.other_document.name, application.other_document.read())
        return email
